/*
 *	@(#)$Id: Informix.h,v 57.2 1997/07/30 03:13:26 johnl Exp $ 
 *
 * Portions Copyright (c) 1994,1995 Tim Bunce
 * Portions Copyright (c) 1995,1996 Alligator Descartes
 * Portions Copyright (c) 1996,1997 Jonathan Leffler
 *
 * You may distribute under the terms of either the GNU General Public
 * License or the Artistic License, as specified in the Perl README file.
 */

/*TABSTOP=4*/

#ifndef INFORMIX_H
#define INFORMIX_H

#define NEED_DBIXS_VERSION 9

#include <DBIXS.h>		/* Installed by the DBI module */
#include "dbdimp.h"		/* Informix implementation details */
#include <dbd_xsh.h>	/* Installed by the DBI module */

#endif /* INFORMIX_H */
